function sto2welf
% STO2WELF Solves the floor-price model and calculates welfare changes

%% Pack model structures
Mu                = 1;
sigma             = 0.05;
model1 = recsmodelinit('sto1welf.yaml',struct('Mu',Mu,'Sigma',sigma^2,'order',7));
model2 = recsmodelinit('sto2welf.yaml',struct('Mu',Mu,'Sigma',sigma^2,'order',7));

%% Define approximation space
[interp1,s] = recsinterpinit(50,0.7,2);
interp2     = interp1;

%% Find a first guess through the perfect foresight solution
interp1 = recsFirstGuess(interp1,model1,s,model1.sss,model1.xss,5);
interp2 = recsFirstGuess(interp2,model2,s,model2.sss,model2.xss,5);

%% Solve for rational expectations (option: hide iterations)
[interp1,x1] = recsSolveREE(interp1,model1,s,[],struct('display',0));
[interp2,x2] = recsSolveREE(interp2,model2,s,[],struct('display',0));

%% Long-run simulation
[~,~,~,~,stat] = recsSimul(model1,interp1,ones(1E4,1),200);
[~,~,~,~,stat] = recsSimul(model2,interp2,ones(1E4,1),200);

%% Welfare change
sinit = [1 0.2];
[W1,W2] = WelfareCalculation([1 0.2]);
DW = W2-W1;
disp('Welfare change:')
disp(DW)
fid = fopen('./Published/sto2welf.tex','w');
fwrite(fid,latex([DW(2:end) DW(1)],'%0.4f'));
fclose(fid);

%% Plot social welfare against initial availability
n   = 100;
res = zeros(n,1);
H0  = linspace(0.8,1.7,n);
for i=1:n
  [W1,W2] = WelfareCalculation([H0(i) 0]);
  res(i) = W2(1)-W1(1);
end
figure
plot(H0,res)
xlabel('Initial availability')
ylabel('Change in social welfare')
set(gcf,'Color','w')
export_fig sto2welf.eps

function [Welf1,Welf2] = WelfareCalculation(sinit)
  % sinit is the decomposition of initial state between production and private
  % stock: [H*eps (1-delta)*S]

  %% Simulate the model for a given initial state variable to get welfare values
  [~,xsim1] = recsSimul(model1,interp1,sum(sinit),0);
  [~,xsim2] = recsSimul(model2,interp2,sum(sinit),0);

  P0   = [xsim1(3) xsim2(3)];
  beta = 1/(1+model1.params(3));

  %% Calculate welfare
  Welf1 = [xsim1(4:5) P0(1)*sinit(1)+xsim1(6) P0(1)*sinit(2)        0]*(1-beta);
  Welf2 = [xsim2(5:6) P0(2)*sinit(1)+xsim2(7) P0(2)*sinit(2) xsim2(8)]*(1-beta);
end

end